from enum import StrEnum


class Fingerprint(StrEnum):
    CHROME = "chrome"
    FIREFOX = "firefox"
    SAFARI = "safari"
    IOS = "ios"
    ANDROID = "android"
    EDGE = "edge"
    QQ = "qq"
    RANDOM = "random"
    RANDOMIZED = "randomized"
