from enum import StrEnum


class TemplateType(StrEnum):
    STASH = "STASH"
    SINGBOX = "SINGBOX"
    SINGBOX_LEGACY = "SINGBOX_LEGACY"
    MIHOMO = "MIHOMO"
    XRAY_JSON = "XRAY_JSON"
    CLASH = "CLASH"
